@@ -870,9 +870,9 @@ class BaseExperiment:
         best_model_metadata = None
         best_version = None
         for model_type_dir in os.listdir(jsonlogdir):
-            for metadata in os.listdir(model_type_dir):
-                for version in os.listdir(metadata):
-                    for file in os.listdir(version):
+            for metadata in os.listdir(f'{jsonlogdir}/{model_type_dir}'):
+                for version in os.listdir(f'{jsonlogdir}/{model_type_dir}/{metadata}'):
+                    for file in os.listdir(f'{jsonlogdir}/{model_type_dir}/{metadata}/{version}'):
                         with open(f"{model_type_dir}/{version}/{file}", "r") as json_file:
                             logs = json.load(json_file)
                             val_score = logs[val_metric] if isinstance(logs[val_metric], float) else logs[val_metric][-1]
